@@ -1,3 +1,4 @@
+import json
 from pathlib import Path
 
 from cookiecutter.exceptions import FailedHookException, OutputDirExistsException
@@ -10,16 +11,16 @@ from fastapi_template.input_model import BuilderContext
 script_dir = Path(__file__).parent
 
 
-def main():
-    try:
-        context = get_context()
-    except KeyboardInterrupt:
-        print("Goodbye!")
-        return
+def generate_project(context: BuilderContext) -> None:
+    """
+    Generate actual project with given context.
+
+    :param context: builder_context
+    """
     try:
         cookiecutter(
             template=f"{script_dir}/template",
-            extra_context=context.dict(),
+            extra_context=json.loads(context.json()),
             default_config=BuilderContext().dict(),
             no_input=True,
             overwrite_if_exists=context.force,
@@ -33,5 +34,15 @@ def main():
     )
 
 
+def main() -> None:
+    """Starting point."""
+    try:
+        context = get_context()
+    except KeyboardInterrupt:
+        print("Goodbye!")
+        return
+    generate_project(context)
+
+
 if __name__ == "__main__":
     main()
